@@ -400,6 +400,7 @@ class TreesappTester(unittest.TestCase):
                                "--treesapp_output", get_test_data("assign_SwissProt_PuhA/"),
                                "--output", "./TreeSAPP_update",
                                "--num_proc", str(self.num_procs),
+                               "--min_seq_length", str(100),
                                "--trim_align", "--cluster", "--fast", "--headless",
                                "--overwrite", "--delete", "--skip_assign", "--resolve"]
         update(update_command_list)
@@ -430,10 +431,10 @@ class TreesappTester(unittest.TestCase):
         return
 
     # def test_tmp(self):
-    #     from treesapp import assign
+    #     from treesapp import commands
     #     os.chdir("")
     #     cmd = ""
-    #     assign.assign(cmd.split())
+    #     commands.create(cmd.split())
     #     return
 
 
