@@ -14,12 +14,16 @@ class UpdaterTester(unittest.TestCase):
 
     def test_decide_length_filter(self):
         from treesapp import update_refpkg as ts_update_mod
-        min_length = ts_update_mod.decide_length_filter(self.ref_pkg, proposed_min_length=800)
-        self.assertEqual(800, min_length)
+        min_length = ts_update_mod.decide_length_filter(self.ref_pkg, proposed_min_length=500)
+        self.assertEqual(500, min_length)
 
         # Ensure the incorrectly-provided percentage is converted to a proportion
         min_length = ts_update_mod.decide_length_filter(self.ref_pkg, min_hmm_proportion=80)
         self.assertEqual(443, min_length)
+
+        # Ensure the minimum length provided is used, not the HMM proportion
+        min_length = ts_update_mod.decide_length_filter(self.ref_pkg, proposed_min_length=800, min_hmm_proportion=80)
+        self.assertEqual(800, min_length)
         return
 
     def test_simulate_entrez_records(self):
@@ -33,7 +37,7 @@ class UpdaterTester(unittest.TestCase):
         fa.header_registry = register_headers(list(fa.fasta_dict.keys()))
         lin_map = {"AB-750_E14_NODE_11_length_29119_cov_8.74474_ID_15_7": "d__Bacteria;p__Proteobacteria",
                    "2509738965_Desulfomonile_tiedjei_DCB|HgcB|1_200": "d__Bacteria; p__Proteobacteria; c__Deltaproteobacteria; o__Syntrophobacterales; f__Syntrophaceae"}
-        fa.change_dict_keys("num")
+        fa.change_dict_keys("num_id")
 
         # Test to ensure sequences with same prefix have different EntrezRecord instances
         entrez_records = simulate_entrez_records(fasta_records=fa, seq_lineage_map=lin_map)
