@@ -274,6 +274,8 @@ def train(sys_args):
                                                                   ts_trainer.stage_output_dir,
                                                                   max_examples=args.max_examples,
                                                                   num_threads=args.num_threads)
+            if not clade_ex_pqueries:
+                return
             jdump(value=clade_ex_pqueries, filename=os.path.join(ts_trainer.clade_ex_pquery_pkl))
 
         # Write the tab-delimited file with metadata included for each placement
@@ -511,7 +513,7 @@ def create(sys_args):
     if ts_create.stage_status("cluster"):
         # TODO: replace with fasta.dereplicate_by_clustering()
         pre_cluster = ref_seqs.n_seqs()
-        ref_seqs.change_dict_keys("num")
+        ref_seqs.change_dict_keys("num_id")
         # Write a FASTA for clustering containing the formatted headers since
         # not all clustering tools + versions keep whole header - spaces are replaced with underscores
         fasta.write_new_fasta(fasta_dict=ref_seqs.fasta_dict,
@@ -700,15 +702,18 @@ def create(sys_args):
 
     if ts_create.stage_status("train"):
         train(trainer_cmd)
+        trained_refpkg = os.path.join(ts_create.var_output_dir, "placement_trainer", "final_outputs",
+                                      ts_create.ref_pkg.prefix + ts_create.ref_pkg.refpkg_suffix)
     else:
         LOGGER.info("Skipping training:\n$ treesapp train {}.\n".format(' '.join(trainer_cmd)))
+        trained_refpkg = ''
 
     ##
     # Finish validating the file and append the reference package build parameters to the master table
     ##
     if ts_create.stage_status("update"):
-        ts_create.ref_pkg.f__pkl = os.path.join(ts_create.var_output_dir, "placement_trainer", "final_outputs",
-                                                ts_create.ref_pkg.prefix + ts_create.ref_pkg.refpkg_suffix)
+        if os.path.isfile(trained_refpkg):
+            ts_create.ref_pkg.f__pkl = trained_refpkg
         ts_create.ref_pkg.slurp()
         ts_create.ref_pkg.validate()
         ts_create.ref_pkg.change_file_paths(ts_create.final_output_dir)
@@ -725,7 +730,7 @@ def update(sys_args):
     treesapp_args.add_update_arguments(parser)
     args = parser.parse_args(sys_args)
 
-    ts_updater = classy.Updater()
+    ts_updater = ts_update_mod.Updater()
     ts_updater.furnish_with_arguments(args)
     ts_updater.check_previous_output(args.overwrite)
 
@@ -848,7 +853,7 @@ def update(sys_args):
         # The purpose of this block is to remove any former candidate reference sequences from the ref_fasta object
         # that have a more truncated lineage that the new candidate reference sequences in combined_fasta
         ##
-        combined_fasta.change_dict_keys("num")
+        combined_fasta.change_dict_keys("num_id")
         # Write a FASTA for clustering containing the formatted headers since
         # not all clustering tools + versions keep whole header - spaces are replaced with underscores
         fasta.write_new_fasta(fasta_dict=combined_fasta.fasta_dict,
