@@ -1,12 +1,13 @@
-__author__ = 'Connor Morgan-Lang'
-
-
 import re
 import logging
 
 from pygtrie import StringTrie
 
-from .utilities import median
+from treesapp.utilities import median
+from treesapp import taxonomic_hierarchy
+from treesapp import logger
+
+LOGGER = logging.getLogger(logger.logger_name())
 
 
 def optimal_taxonomic_assignment(trie: StringTrie, query_taxon: str):
@@ -54,9 +55,9 @@ def identify_excluded_clade(assignment_dict: dict, trie: StringTrie) -> dict:
                     log_stats += "\t\tOptimal lineage: " + contained_taxonomy + "\n"
                 rank_assigned_dict[rank_excluded].append({ref_lineage: (contained_taxonomy, query_lineage)})
             else:
-                logging.warning("Number of ranks in lineage '{}' is ridiculous.\n"
+                LOGGER.warning("Number of ranks in lineage '{}' is ridiculous.\n"
                                 "This will not be used in clade exclusion calculations\n".format(contained_taxonomy))
-    logging.debug(log_stats + "\n")
+    LOGGER.debug(log_stats + "\n")
     return rank_assigned_dict
 
 
@@ -94,7 +95,7 @@ def megan_lca(lineage_list: list):
         else:
             i = max_depth
     if len(lca_lineage_strings) == 0:
-        logging.debug("Empty LCA from lineages:\n\t" + "\n\t".join(lineage_list) + "\n")
+        LOGGER.debug("Empty LCA from lineages:\n\t" + "\n\t".join(lineage_list) + "\n")
         lca_lineage_strings.append("Unclassified")
 
     return "; ".join(lca_lineage_strings)
@@ -114,7 +115,7 @@ def weighted_taxonomic_distance(lineage_list, common_ancestor):
     for lineage in lineage_list:
         distance, status = compute_taxonomic_distance(lineage, common_ancestor)
         if status:
-            logging.debug("Taxonomic lineages didn't converge between " + common_ancestor + " and " + lineage + ".\n")
+            LOGGER.debug("Taxonomic lineages didn't converge between " + common_ancestor + " and " + lineage + ".\n")
         status += 1
 
         numerator += 2**distance
@@ -224,3 +225,39 @@ def clean_lineage_list(lineage_list):
         return classified_lineages
     else:
         return lineage_list
+
+
+def taxonomic_distinctness(query_taxa: dict, rank: str, rank_depths: dict) -> float:
+    count_attr = "weight"
+    ranked_taxa = []
+    count_weights = {}
+    # Instantiate the weight attribute
+    for taxon in query_taxa.values():
+        for rt in taxon.lineage():
+            setattr(rt, count_attr, 0)
+
+    for _qry, taxon in query_taxa.items():  # type: (str, taxonomic_hierarchy.Taxon)
+        rt = taxon.get_rank_in_lineage(rank)
+        if rt is None:
+            rt = taxon
+        setattr(rt, count_attr, getattr(rt, count_attr)+1)
+        if rt not in ranked_taxa:
+            ranked_taxa.append(rt)
+
+    i, j = 0, 0
+    while i < len(ranked_taxa):
+        while j < len(ranked_taxa):
+            lca = taxonomic_hierarchy.Taxon.lca(ranked_taxa[i], ranked_taxa[j])  # type: taxonomic_hierarchy.Taxon
+            while lca.rank not in rank_depths:
+                lca = lca.parent
+            path_len = rank_depths[rank] - rank_depths[lca.rank]
+            try:
+                count_weights[path_len].append(getattr(ranked_taxa[i], count_attr)*getattr(ranked_taxa[j], count_attr))
+            except KeyError:
+                count_weights[path_len] = [getattr(ranked_taxa[i], count_attr)*getattr(ranked_taxa[j], count_attr)]
+            j += 1
+        i += 1
+
+    cross_product = sum([n*sum(count_weights[n]) for n in count_weights])
+    denominator = sum([sum(count_weights[n]) for n in count_weights])
+    return cross_product/denominator
