@@ -97,7 +97,7 @@ def read_placement_summary(placement_summary_file: str) -> dict:
                         dists = [float(dist) for dist in dist_strings]
                     except ValueError:
                         LOGGER.error("Looks like treesapp train did not complete successfully.\n"
-                                      "Please re-run with the flag '--overwrite'.\n")
+                                     "Please re-run with the flag '--overwrite'.\n")
                         sys.exit(5)
                     if len(dists) > 1:
                         taxonomic_placement_distances[rank] = dists
@@ -145,7 +145,7 @@ def prepare_training_data(test_seqs: fasta.FASTA, output_dir: str, executables:
                           t_hierarchy: TaxonomicHierarchy, accession_lineage_map: dict, taxonomic_ranks=None) -> dict:
     """
     Function for creating a non-redundant inventory of sequences to be used for training the rank-placement distance
-    linear model. Removes sequences that share an identical accession, are more than 97% similar and limits the
+    linear model. It removes sequences that share an identical accession, are more than 97% similar and limits the
     number of taxonomically-identical sequences to 30.
 
     :param test_seqs: A FASTA object. All headers in FASTA.header_registry must have their accession attribute filled
@@ -187,7 +187,6 @@ def prepare_training_data(test_seqs: fasta.FASTA, output_dir: str, executables:
     test_seqs.dedup_by_accession()
     # Remove fasta records with duplicate sequences
     test_seqs.dedup_by_sequences()
-    test_seqs.change_dict_keys("accession")
 
     # Remove sequences that are not related at the rank of Domain
     ref_domains = t_hierarchy.rank_representatives("domain", True)
@@ -201,10 +200,10 @@ def prepare_training_data(test_seqs: fasta.FASTA, output_dir: str, executables:
             related_queries.append(seq_name)
     if not related_queries:
         LOGGER.error("No sequences were retained after filtering reference sequences by domains '%s'\n" %
-                      str(', '.join(ref_domains)))
+                     str(', '.join(ref_domains)))
         sys.exit(5)
 
-    related_queries_in_fasta = list(set(test_seqs.fasta_dict.keys()).intersection(set(related_queries)))
+    related_queries_in_fasta = test_seqs.careful_header_intersection(related_queries)
     test_seqs.keep_only(related_queries_in_fasta)
     test_seqs.change_dict_keys("accession")
     [accession_lineage_map.pop(seq_name) for seq_name in unrelated_queries]
@@ -248,25 +247,25 @@ def prepare_training_data(test_seqs: fasta.FASTA, output_dir: str, executables:
 
         if taxonomic_coverage < warning_threshold:
             LOGGER.warning("Only {0}% of unique {1}-level taxa can be used represent"
-                            " {1} phylogenetic placements.\n".format(taxonomic_coverage, rank))
+                           " {1} phylogenetic placements.\n".format(taxonomic_coverage, rank))
 
         test_taxa_summary.append("%d/%d unique %s-level taxa have training sequences.\n" % (represented_taxa,
                                                                                             len(unique_ref_lineages),
                                                                                             rank))
         LOGGER.debug("%.1f%% of optimal %s lineages are present in the pruned trees.\n" %
-                      (round(float(optimal_lineages_present*100/len(unique_ref_lineages)), 1), rank))
+                     (round(float(optimal_lineages_present*100/len(unique_ref_lineages)), 1), rank))
         optimal_lineages_present = 0
         represented_taxa = 0
 
     LOGGER.debug("Optimal placement target was not found in the pruned tree for following taxa:\n\t" +
-                  "\n\t".join(optimal_assignment_missing) + "\n")
+                 "\n\t".join(optimal_assignment_missing) + "\n")
     
     LOGGER.debug("Unable to generate placement data for the following taxa since the refpkg would be too small:\n\t" +
-                  "\n\t".join(too_short) + "\n")
+                 "\n\t".join(too_short) + "\n")
 
     LOGGER.debug("\n".join(test_taxa_summary) + "\n")
 
-    test_seqs.change_dict_keys("num")
+    test_seqs.change_dict_keys("num_id")
     fasta.write_new_fasta(test_seqs.fasta_dict, clustering_input)
     wrapper.cluster_sequences(executables["mmseqs"], clustering_input, clustering_prefix, similarity)
     cluster_dict = seq_clustering.create_mmseqs_clusters(clusters_tbl=clustering_prefix + "_cluster.tsv",
@@ -409,10 +408,10 @@ def evo_dists_from_pqueries(pqueries: dict, training_ranks=None) -> dict:
         mean_dist = round(utilities.mean(taxonomic_placement_distances[rank]), 4)
 
         LOGGER.debug("RANK: {}\n"
-                      "\tSamples = {}\n"
-                      "\tMedian = {}\n"
-                      "\tMean = {}\n"
-                      "".format(rank, len(taxonomic_placement_distances[rank]), median_dist, mean_dist))
+                     "\tSamples = {}\n"
+                     "\tMedian = {}\n"
+                     "\tMean = {}\n"
+                     "".format(rank, len(taxonomic_placement_distances[rank]), median_dist, mean_dist))
     return taxonomic_placement_distances
 
 
@@ -484,7 +483,7 @@ def gen_cladex_data(fasta_input: str, executables: dict, ref_pkg: ReferencePacka
     :param executables: A dictionary containing executable names mapped to absolute paths of the executables
     :param ref_pkg: A ReferencePackage instance
     :param accession_lineage_map: Path to a file mapping query sequence accessions to their taxonomic lineage
-    :param output_dir: Path the a directory to write the temporary files
+    :param output_dir: Path to the directory to write the temporary files
     :param max_examples: The maximum number of examples to use for training the reference package's models
     :param num_threads: The number of threads to be used by the various dependencies during phylogenetic placement
     :return:
